@@ -304,6 +304,16 @@ fn parse_expr(pair: Pair<Rule>, source: ModuleId) -> Ctx<RawExpr> {
             let body = parse_expr(children.next().unwrap(), source);
             RawExpr::Let(var_name, var_binding, body).with_ctx(ctx)
         }
+        Rule::let_q_expr => {
+            let mut children = pair.into_inner();
+            let var_name = children.next().unwrap();
+            let var_name = Symbol::from(var_name.as_str()).with_ctx(p2ctx(&var_name, source));
+            let var_binding = parse_expr(children.next().unwrap(), source);
+            let body = parse_expr(children.next().unwrap(), source);
+            let body_container =
+                RawExpr::BinOp(BinOp::Land.into(), RawExpr::Var(*var_name).into(), body);
+            RawExpr::Let(var_name, var_binding, body_container.into()).with_ctx(ctx)
+        }
         Rule::for_expr => {
             let mut children = pair.into_inner();
             let var_name = children.next().unwrap();
@@ -323,7 +333,7 @@ fn parse_expr(pair: Pair<Rule>, source: ModuleId) -> Ctx<RawExpr> {
             let body = parse_expr(children.next().unwrap(), source);
             RawExpr::ForFold(var_name, var_binding, accum_name, accum_binding, body).with_ctx(ctx)
         }
-        Rule::rel_expr | Rule::add_expr | Rule::mult_expr => {
+        Rule::rel_expr | Rule::add_expr | Rule::mult_expr | Rule::logic_expr => {
             let mut children: Vec<_> = pair.into_inner().collect();
             let mut toret = parse_expr(children.remove(0), source);
             for pair in children.chunks_exact(2) {
@@ -522,7 +532,7 @@ mod tests {
             "{:?}",
             parse_program(
                 r#"def range<$n>(x: {$n..$n}) =
-                    let accum = [] in
+                    let accum = [] in 
                     let ctr = 0 :: Nat in
                     accum
             "#,
